# REST API reference

<!--
Generated using assets/openapi.json - a copy of the autogenerated spec by FAastAPI, ref: https://fastapi.tiangolo.com/features/#automatic-docs

Presented using Swagger UI, ref: https://swagger.io/tools/swagger-ui/
-->

<link type="text/css" rel="stylesheet" href="https://cdn.jsdelivr.net/npm/swagger-ui-dist@5/swagger-ui.css">
<script src="https://cdn.jsdelivr.net/npm/swagger-ui-dist@5/swagger-ui-bundle.js"></script>

<!-- Render the Swagger UI -->
<div id="swagger-ui"></div>

<!-- https://swagger.io/docs/open-source-tools/swagger-ui/usage/configuration/ -->
<script>
const docs_root = window.location.pathname.split('/').slice(0, -3).join('/');
const ui = SwaggerUIBundle({
  url: `${docs_root}/references/openapi.json`,
  dom_id: '#swagger-ui',
  presets: [
    SwaggerUIBundle.presets.apis,
    SwaggerUIBundle.SwaggerUIStandalonePreset
  ],
  layout: "BaseLayout",
  tryItOutEnabled: false,
  supportedSubmitMethods: [],
});
</script>
